Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'spec/lib/gitlab/other_markup_spec.rb')
-rw-r--r--spec/lib/gitlab/other_markup_spec.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/spec/lib/gitlab/other_markup_spec.rb b/spec/lib/gitlab/other_markup_spec.rb
index 6b4b0e8fda6..74e2c5e26c1 100644
--- a/spec/lib/gitlab/other_markup_spec.rb
+++ b/spec/lib/gitlab/other_markup_spec.rb
@@ -35,8 +35,8 @@ RSpec.describe Gitlab::OtherMarkup do
end
it 'times out' do
- # expect twice because of timeout in SyntaxHighlightFilter
- expect(Gitlab::RenderTimeout).to receive(:timeout).twice.and_call_original
+ # expect 3 times because of timeout in SyntaxHighlightFilter and BlockquoteFenceFilter
+ expect(Gitlab::RenderTimeout).to receive(:timeout).exactly(3).times.and_call_original
expect(Gitlab::ErrorTracking).to receive(:track_exception).with(
instance_of(Timeout::Error),
project_id: context[:project].id, file_name: file_name,